summaryrefslogtreecommitdiff
path: root/framework
diff options
context:
space:
mode:
authorChad Versace <chad.versace@intel.com>2011-01-24 17:15:44 -0800
committerChad Versace <chad.versace@intel.com>2011-01-25 12:42:35 -0800
commitae8d0a589d40548641ec0f8d6578c7ae073a174e (patch)
tree328371559e640951f9f606b8d31bf316dded5b98 /framework
parentf183de62da3aca11186d713f058a45a4ce8267dd (diff)
glsl_parser_test: Rename config opt 'extension' to 'require_extensions'
... and update all test file using the option. The new name makes clear what the option does.
Diffstat (limited to 'framework')
-rwxr-xr-xframework/glsl_parser_test.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/framework/glsl_parser_test.py b/framework/glsl_parser_test.py
index c3fa2d9a..d5fdd5ea 100755
--- a/framework/glsl_parser_test.py
+++ b/framework/glsl_parser_test.py
@@ -129,7 +129,7 @@ class GLSLParserTest(PlainExecTest):
Nonrequired Options
-------------------
- * extensions: List of GL extensions. If an extension is not
+ * require_extensions: List of GL extensions. If an extension is not
supported, the test is skipped. Each extension name must begin
with GL and elements are separated by whitespace.
@@ -140,7 +140,7 @@ class GLSLParserTest(PlainExecTest):
// glsl_version: 1.30
// expect_result: pass
// # Lists may be single-line.
- // extensions: GL_ARB_fragment_coord_conventions GL_AMD_conservative_depth
+ // require_extensions: GL_ARB_fragment_coord_conventions GL_AMD_conservative_depth
// [end config]
::
@@ -148,7 +148,7 @@ class GLSLParserTest(PlainExecTest):
* glsl_version: 1.30
* expect_result: pass
* # Lists may be span multiple lines.
- * extensions:
+ * required_extensions:
* GL_ARB_fragment_coord_conventions
* GL_AMD_conservative_depth
* [end config]
@@ -366,7 +366,7 @@ class GLSLParserTest(PlainExecTest):
self.config.get('config', 'expect_result'),
self.config.get('config', 'glsl_version')
]
- command += self.config.get('config', 'extensions').split()
+ command += self.config.get('config', 'require_extensions').split()
return command
@property